<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>退出內測您將無法獲取內測更新</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退 出</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation>查看更新日誌</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>更新歷史記錄</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>無更新歷史記錄</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>系統更新</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>安全更新</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>提供新功能、質量補丁、安全漏洞等全量更新內容</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>提供安全漏洞修復</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>安裝時間:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>查看詳細信息</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>發佈時間：</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>收起</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>版本：</translation>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation>更新日誌</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation>導出至桌面</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>低危</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>中危</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>高危</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>嚴重</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>嚴重</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>高危</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>中危</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>低危</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>本次更新修復</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>漏洞</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>漏洞</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1個%2%3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation type="unfinished"/>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation type="unfinished"/>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>正在檢查更新，請等待…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>您的系統已更新</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知錯誤</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>更新包下載失敗，請釋放%1空間</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>依賴錯誤，檢測更新失敗</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>請檢查網絡後重試</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>更新包下載失敗，請檢查網絡後重試</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>系統無法備份，繼續升級，系統將無法回退</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>繼續更新，系統將無法回退</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>磁盤空間不足</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkg錯誤</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>部分文件缺失</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>服務連接異常，請檢查網絡後重試</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>倉庫源配置錯誤，請檢查後再試。</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>重新檢查更新</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>《私隱政策》</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>使用此軟件需要接受軟件更新時附帶的%1</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>開啓更新內容開關，可以獲得更優質的功能體驗哦</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>當前系統未激活，無法啓動更新服務</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>系統已被禁止更新，請聯繫管理員！</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation>系統已開啓無憂還原功能，不支持更新，如有疑問請聯繫企業管理員</translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation>更新包已下載完畢，請選擇您要執行的操作</translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation>後台靜默安裝</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>更新並重啓</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>更新並關機</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>智能鏡像源</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>更新類型</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>功能更新</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>提供新功能、質量補丁、安全漏洞修復登全量更新內容</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>安全更新</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>提供安全漏洞修復</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>第三方來源更新</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>提供額外添加的倉庫源更新內容</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>下載限速</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>限速設置</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>自動下載</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>開啓「自動下載」，會在聯網的情況下自動下載更新包</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>閒時下載</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>開始時間</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>結束時間</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>高級設置</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>更新提醒</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>清除軟件包緩存</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>歷史更新內容</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>內測通道</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>點擊此處完成內測申請</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>展開</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation>論壇2級及以上用户可加入內測，獲取最新更新</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>收起</translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation>只允許輸入1-99999</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>系統更新</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>修復部分已知缺陷和安全漏洞</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>安全更新</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>第三方倉庫</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation>更新日誌</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>日誌導出失敗，請重試嘗試</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>日誌已導出至桌面</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>系統更新</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>系統更新升級</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>更新設置</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>正在安裝</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>更新下載完成</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>安裝更新</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>更新下載失敗</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>下載更新中...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>下載中</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>可設置系統更新、安全更折、閒時更新、更新提醒等</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>立即重啓</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下 載</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>正在安裝更新...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>重 試</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>繼續更新</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>檢測到有可用的更新</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>安裝更新失敗</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>為了您能夠正常使用系統和應用，更新後請重啓電腦</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>正在備份...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>正在備份</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>備份失敗</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>更新安裝成功</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>繼續更新，系統將無法回退</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>重試</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>繼續更新</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>電池電量低於60%，為保障更新成功，請及時接入電源</translation>
    </message>
</context>
</TS>